#
# spec file for package perl-Net-SSLeay
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with test

Name:           perl-Net-SSLeay
Version:        1.64
Release:        6.17
%define cpan_name Net-SSLeay
Summary:        Perl extension for using OpenSSL
License:        OpenSSL
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Net-SSLeay/
Source:         http://www.cpan.org/modules/by-module/Net/Net-SSLeay-%{version}.tar.gz
Patch1:         disable-failing-1.0.1n-tests.patch
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}
%if %{with test}
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(Test::NoWarnings)
BuildRequires:  perl(Test::Pod) >= 1.00
BuildRequires:  perl(Test::Pod::Coverage)
BuildRequires:  perl(Test::Warn)
%endif
#

%description
There is a related module called Net::SSLeay::Handle included in this
distribution that you might want to use instead. It has its own pod
documentation.

%prep
%setup -q -n %{cpan_name}-%{version}
%patch1 -p1
# replace rest of /usr/local/bin/perl with /usr/bin/perl
for f in $(find . -type f -exec grep -l "/usr/local/bin/perl" {} \; ); do
  sed -i -e "s@/usr/local/bin/perl@perl@g" $f
done
# delete .orig files created by patches
find . -type f -name "*.orig" -delete 
# fix perm
pushd examples
chmod 0644 *.pl
popd

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags} -Wall"
make %{?_smp_mflags}

%check
%if ! 0%{?qemu_user_space_build}
make test
%endif

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
rm -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changes Credits QuickRef README examples

%changelog
* Wed Jun  1 2016 pjanouch@suse.de
- added disable-failing-1.0.1n-tests.patch (bsc#982234)
  Removed a test in t/local/33_x509_create_cert.t which fails due
  to changes in 1.0.1n and later (backported from 1.70)
* Thu Jun 12 2014 meissner@suse.com
- updated to 1.64
  Fixes for test ocsp.t. Test now does not fail if HTTP::Tiny is not
  installed.
  Fixed repository in META.yml.
  Fixed a problem with SSL_get_peer_cert_chain: if the SSL handshake
  results in an anonymous authentication, like ADH-DES-CBC3-SHA,
  get_peer_cert_chain will not return an empty list, but instead return the
  SSL object. Reported and fixed by Steffen
  Ullrich. Thanks.
  Fixed a problem where patch
  https://git.openssl.org/gitweb/?p=openssl.git;a=commit;h=3009244da47b989c4cc59ba02cf81a4e9d8f8431
  caused a failed test in t/local/33_x509_create_cert.t.
* Fri Jun  6 2014 coolo@suse.com
- updated to 1.63
  1.63 2014-05-19
    Fixed error in version number in META.yml
  1.62 2014-05-19
    Improvements to OCSP support: It turns out that some CA (like Verisign)
    sign the OCSP response with the CA we have in the trust store and don't
    attach this certifcate in the response.  But OpenSSL by itself only
    considers the certificates included in the response and
    SSL_OCSP_response_verify added the certificates in the chain too.
    Now, we also add the trusted CA from the store which
    signed the lowest chain certificate, at least if we could not verify the
    OCSP response without doing it. Patch from Steffen
    Ullrich. Thanks.
    Fixed some compiler warnings.
  1.61 2014-05-12
    Changes calloc to Newx and free to Safefree, otherwise there might be
    problems because calloc is done from a different memory pool than free (depends
    on the build options for perl, but seen on Windows). Patch from Steffen
    Ullrich. Thanks.
  1.60 2014-05-10
    Fixed a typo in an error message. Patch from gregor herrmann. Thanks.
    Fixed a problem with building with openssl that does not support
    OCSP. Also fixed some newly introduced warnings
    if compiled with -Wall. Patch from Steffen Ullrich. Thanks.
    fix build-failure on most Debian architectures:
    SSLeay.xs: In function 'XS_Net__SSLeay_OCSP_response_results':
    SSLeay.xs:5602:3: error: format not a string literal and no format
    arguments. Patch from  gregor herrmann.
  1.59 2014-05-10
    Fixed local/30_error.t, so that tests do not fail if diagnostics are
    enabled.
    Fixed error messages about undefined strings used with length or
    split. Reported and patched by Peter Heuchert.
    Improvements to configuration of OPTIMIZE flags, to prevent overriding
    of perls expected optimization flags. Caution: HPUX aCC optimize options are special.
    SSL_peek() now returns openssl error code as second item when called in
    array context, same as SSL_read. Patch from Andreas Mohr.
    Fixed some warnings.
    Added support for tlsv1.1 tlsv1.2 via $Net::SSLeay::ssl_version. Patch
    from Andreas Mohr.
    Improve examples in 'Using other perl modules based on
    Net::SSLeay'. Patched by Andreas Mohr.
    Added support for OCSP. Patched by Steffen Ullrich. Thanks!
    Added missing t/external/ocsp.t
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.58
    Always use size_t for strlen() return value, requested by Alexander Bluhm.
    t/external/20_cert_chain.t was missing from dist.
    Version number in META.yml was incorrect
    Improvements to test t/external/20_cert_chain.t to provoke following bug:
    Fixed crash due to SSL_get_peer_cert_chain incorrectly free'ing the chain
    after use.
    Fixed a problem when compiling against openssl where OPENSSL_NO_EC is set.
  1.57 2014-01-09
    Fixed remaining problems with test suite: pod coverage and kwalitee tests
    are only enabled with RELEASE_TESTING=1
  1.56 2014-01-08
    Fixed a typo in documentation of BEAST Attack, patched by gregor
    herrmann.
    Added LICENSE file copied form OpenSSL distribution to prevent complaints
    from various versions of kwalitee.
    Adjusted license: in META.yml to be 'openssl'
    Adds support for the basic operations necessary to support ECDH for PFS,
    e.g. EC_KEY_new_by_curve_name, EC_KEY_free and SSL_CTX_set_tmp_ecdh.
    Improvements to t/handle/external/50_external.t to handle the case when a
    test connection was not possible. Patched by Alexandr Ciornii.
    Added support for ALPN TLS extension. Patch from Lubomir Rintel. Tested
    with openssl-1.0.2-stable-SNAP-20131205.
    Fix an use-after-free error. Patch from Lubomir Rintel.
    Fixed a problem with  Invalid comparison on OBJ_cmp result in
    t/local/36_verify.t. Contributed by paul.
    Added support for get_peer_cert_chain(). Patch by Markus Benning.
    Fixed a bug that could cause stack faults: mixed up PUTBACK with SPAGAIN in ssleay_RSA_generate_key_cb_invoke()
    a final PUTBACK is needed here. A second issue is also fixed:
    cb->data defaults to &PL_sv_undef but throught the code you do not check
    against &PL_sv_undef, just NULL.
    To avoid passing the 3rd optional arg at all, do not create it. This fixes all the
    cb->data checks and wrong refcounts on &PL_sv_undef. Patched by Reini Urban.
    Deleted support for SSL_get_tlsa_record_byname: it is not included in
    OpenSSL git master.
* Wed Oct  2 2013 dmueller@suse.com
- disable checks on qemu user build (hangs)
* Wed Jul  3 2013 lnussel@suse.de
- new version 1.55
  * Added support for TLSV1_1 and TLSV1_2 methods with
    SSL_CTX_tlsv1_1_new(), SSL_CTX_tlsv1_2_new(), TLSv1_1_method() and
    TLSv1_2_method(), where available in the underlying openssl.
  * Added CRL support functions X509_CRL_get_ext(),
    X509_CRL_get_ext_by_NID(), X509_CRL_get_ext_count(). Patch from
    Franck Youssef.
  * Added support for SSL_get_tlsa_record_byname() required for DANE
    support in openssl*1.0.2 and later. SSL_get_tlsa_record_byname()
    was added to OpenSSL with the financial assistance of .SE.
  * Added X509_NAME_new and X509_NAME_hash, patched by Franck Youssef.
  * Added support for SSL_export_keying_material where present
  * Net::SSLeay::ASN1_INTEGER_get, since it works differntly on 32 and
    64 bit platforms. Updated author and distribution location details
    to airspayce.com
  * Fixed a few compiler warnings in SSLeay.xs.  Most of them are just
    signed/unsigned pointer mismatches but there is one that actually
    fixes returning what would be an arbitrary value off the stack
    from get_my_thread_id if it happened to be called in a
    non*threaded build.
  * Added SSL_set_tlsext_host_name, SSL_get_servername,
    SSL_get_servername_type, SSL_CTX_set_tlsext_servername_callback
    for server side Server Name Indication (SNI) support. Patched by
    kmx.
  * Improvements to Net::SSLeay::read to make it easier to use with
    non*blocking IO Added documentation about how to mitigatxe various
    SSL/TLS vulnerabilities.
  * initializes the SSL library at most once.
  * Patch from kmx to protect SSLeay_add_ssl_algorithms from multiple
    loads and reentrancy in multi*threaded perls.
- remove perl-Net-SSLeay-1.36.diff: no obvious nor documented justification
- remove perl-Net-SSLeay-1.36-undefined.diff: no longer applies
* Thu Jun 14 2012 cfarrell@suse.com
- license update: OpenSSL
* Wed Feb  8 2012 vcizek@suse.com
- update to 1.42
    Fixed incorrect documentation of how to enable CRL checking. Patched
    by Steffen_Ullrich.
    Fixed incorrect letter in Sebastien in Credits. Patch by Neil Bowers.
    Reversed order of the Changes file to be reverse chronological. Patch by
    Neil Bowers.
    Fixed a a compile error when building on Windows with MSVC6. reported and
    patched by "Andrew J. Savige via RT".
  1.41    2011-09-25
    Fixed incorrect const signatures for 1.0 that were causing warnings.
    Patches provided by "Douglas
    Christopher Wilson via RT". Now have clean compile with 0.9.8a through 1.0.0.
  1.40    2011-09-23
    Fixed incorrect argument type in call to SSL_set1_param
    Fixed a number of issues with pointer sizes, patched by "Douglas
    Christopher Wilson via RT". Removed redundant pointer cast tests from t/
    Added Perl version requirements to SSLeay.pm
  1.39    2011-09-21
    Downgraded Module::Install to 0.93 since 1.01 was causing problems in
    the Makefile. Reported by Albert Chin.
  1.38    2011-09-16
  - Fixed a problem with  various symbols that only became
    available in OpenSSL 0.9.8 such as X509_VERIFY_PARAM and
    X509_POLICY_NODE, causing build failures with older versions of
    OpenSSL. Patched by paul.
  1.37    2011-09-16
  - Added X509_get_fingerprint, contributed by Thierry Walrant (with
    minor changes die to the fact that stricmp is not avialable. Cert
    types must be lowercase. Also added test to 07_sslecho.t
  - Added suport for SSL_CTX_set1_param, SSL_set1_param,
    selected X509_VERIFY_PARAM_* OBJ_* functions. Added new test
    t/local/36_verify.t
  - Fixed the prototype for randomize(), it missed one arg, and errors
    are reported with perl 5.10.1 on Windows
  - Fixed an uninitialized value warning in $Net::SSLeay::proxyauth,
    reported by Andrey Rikov.
  - Update so net-ssleay will compile if SSLV2 is not present. Patch
    from Chris Butler.
  - Fixed a problem where sslcat (and possibly other functions) expect RSA keys and will not
    load DSA keys for client certificates. Reported and patched by "Jesse
    DeFer via RT"
  - Removed SSL_CTX_v2_new and SSLv2_method() for OpenSSL 1.0 and later.
  - Added CTX_use_PKCS12_file contributed by "Andrew A. Budkin".
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 13 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- added bcond_with test
* Tue Feb 23 2010 anicka@suse.cz
- update to 1.36
  * Added SSL_CTX_get_client_CA_list sk_X509_NAME_free sk_X509_NAME_num
  sk_X509_NAME_value SSL_get_client_CA_list
  * Added EVP_add_digest and EVP_sha256 (if available)
  * Improve documentation on callback functions.
  * bugfixes
* Sun Dec 20 2009 jengelh@medozas.de
- enable parallel build
* Fri Jul 25 2008 anicka@suse.cz
- update to 1.35
  * Added optional support for SSL_set_hello_extension,
  * Added SSL_SESSION_set_master_key and SSL_get_keyblock_size.
  * Added all SSL_OP_* options flags present in 0.9.9
  * Don't use Module::Installs auto_install.
  * Bind NID_ and GEN_ constants.
  * Default to not running external tests.
  * Added support for ENGINE_load_builtin_engines and
  ENGINE_register_all_complete in order to enable built-in OpenSSL
  crypto engines for hardware acceleration etc.
  * Added support for ENGINE_by_id and ENGINE_set_default, required
  to enable Sun crypto acceleration
- enable all the test again (external are not running by default)
- rename to perl-Net-SSLeay
* Wed May 14 2008 adrian@suse.de
- do not contact remote servers during build, disable check
* Wed Mar 12 2008 anicka@suse.cz
- update to 1.32
  * Removed %%Filenum_Objects from Net::SSLeay::Handle so
  unused handles will be freed.
  * Use ppport.h.
  * improved openssl path guessing, forcing openssl path now
  * Fixed a problem with X509_get_subjectAltNames not working
  when the subjectAltNAmes are the first extension.
  * Fixed incorrect test failure reports in 08_external.
  * Add parens to function calls in Makefile.PL to prevent
  warnings with some perls.
  * Removed auto_include from Makefile.PL
  * Removed build_requires('Test::NoWarnings') from Makefile.PL
  * Don't let the tests die when something unexpected happens.
- fix undefined operation in SSLeay.xs
- add perl-Test-Warn to BuildRequires
* Mon May  7 2007 anicka@suse.cz
- add openssl to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 1.30
- remove X509_STORE_CTX_set_flags patch (not neccessary any more)
* Thu Mar 17 2005 mjancar@suse.cz
- use secure path for entropy (#65753)
* Wed Sep 29 2004 mls@suse.de
- added X509_STORE_CTX_set_flags() function needed to enable
  crl checking. Also fixed the documentation.
* Wed Mar  3 2004 mjancar@suse.cz
- update to 1.25
- disable test running out of memmory in build environment
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue Jun 17 2003 mjancar@suse.cz
- update to 1.23
- kill obsolete patches
- fix filelist
* Fri Jun  6 2003 mjancar@suse.cz
- update to 1.22
- use $RPM_OPT_FLAGS
- don't package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Thu Nov 21 2002 prehak@suse.cz
- updated to version 1.21
- applied patches eliminating security bug [#21903]
* Thu Sep 12 2002 prehak@suse.cz
- updated to version 1.20
- fixed hanged up processes in test -> enabled make test
* Sat Jul 20 2002 prehak@suse.cz
- update to version 1.18
- adjusted %%files section
- added examples directory to documentation
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Jan 14 2002 rvasice@suse.cz
- update to version 1.12
- spec file cleanup
* Thu Oct 11 2001 cihlar@suse.cz
- disabled make test as it leaves processes after build
* Wed Apr  4 2001 schwab@suse.de
- Fix cast to not lose pointer bits.
* Mon Mar 26 2001 cihlar@suse.cz
- fixed AUTOLOAD
- added make test
- remove tests which need network
* Thu Nov 23 2000 cihlar@suse.cz
- fixed neededforbuild
* Fri Nov 10 2000 cihlar@suse.cz
- renamed p_ssleay -> perl-Net_SSLeay
* Wed Aug 23 2000 cihlar@suse.cz
- package created
